@@ -205,7 +205,7 @@ muscle_syncline_grow (char const *key, location loc)
 {
   obstack_printf (&muscle_obstack, "]b4_syncline(%d, ", loc.start.line);
   obstack_quote (&muscle_obstack,
-                 quotearg_style (c_quoting_style, loc.start.file));
+                 quotearg_style (c_quoting_style, map_file_name (loc.start.file)));
   obstack_sgrow (&muscle_obstack, ")dnl\n[");
   char const *extension = obstack_finish0 (&muscle_obstack);
   muscle_grow (key, extension, "", "");
